@@ -392,10 +392,10 @@ class AsyncMysqlService(DBService):
             user=self.user,
             password=self.password,
             db=self.db,
+            autocommit=True,
             minsize=self.minsize,
             maxsize=self.maxsize
         )
-        print('创建连接池')
 
     async def close_pool(self):
         # 关闭连接池
@@ -421,11 +421,12 @@ class AsyncMysqlService(DBService):
     async def transaction(self, queries):
         async with self.pool.acquire() as conn:
             async with conn.cursor() as cur:
+                await conn.begin()
                 try:
-                    await conn.begin()
                     for query in queries:
                         await cur.execute(query)
                     await conn.commit()
+                    return True  # 如果所有操作都成功，返回True
                 except Exception as e:
-                    await cur.execute("ROLLBACK")
-                    raise e
+                    await conn.rollback()
+                    return False  # 如果发生异常，回滚事务并返回False
